==> chromium-62.0.3198.0.tar.xz: chromium-62.0.3198.0/chrome/android/javatests/src/org/chromium/chrome/browser/vr_shell/mock/MockVrDaydreamApi.java <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package org.chromium.chrome.browser.vr_shell.mock;

import android.app.PendingIntent;
import android.content.ComponentName;
import android.content.Intent;

import org.chromium.chrome.browser.vr_shell.VrDaydreamApi;

/**
 * Mock implementation of VR Shell's VrDaydreamApi
 */
public class MockVrDaydreamApi implements VrDaydreamApi {
    private boolean mLaunchInVrCalled;

    @Override
    public boolean isDaydreamReadyDevice() {
        return false;
    }

    @Override
    public boolean registerDaydreamIntent(final PendingIntent pendingIntent) {
        return false;
    }

    @Override
    public boolean unregisterDaydreamIntent() {
        return false;
    }

    @Override
    public Intent createVrIntent(final ComponentName componentName) {
        return new Intent();
    }

    @Override
    public boolean launchInVr(final PendingIntent pendingIntent) {
        mLaunchInVrCalled = true;
        return true;
    }

    @Override
    public boolean launchInVr(final Intent intent) {
        return true;
    }

    @Override
    public boolean exitFromVr(int requestCode, final Intent intent) {
        return true;
    }

    @Override
    public Boolean isDaydreamCurrentViewer() {
        return false;
    }

    @Override
    public void launchVrHomescreen() {}

    public boolean getLaunchInVrCalled() {
        return mLaunchInVrCalled;
    }
}

==> chromium-64.0.3282.71.tar.xz: chromium-64.0.3282.71/chrome/android/javatests/src/org/chromium/chrome/browser/vr_shell/mock/MockVrDaydreamApi.java <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package org.chromium.chrome.browser.vr_shell.mock;

import android.app.PendingIntent;
import android.content.ComponentName;
import android.content.Intent;

import org.chromium.chrome.browser.vr_shell.VrDaydreamApi;

/**
 * Mock implementation of VR Shell's VrDaydreamApi
 */
public class MockVrDaydreamApi implements VrDaydreamApi {
    private boolean mLaunchInVrCalled;

    @Override
    public boolean isDaydreamReadyDevice() {
        return false;
    }

    @Override
    public boolean registerDaydreamIntent(final PendingIntent pendingIntent) {
        return false;
    }

    @Override
    public boolean unregisterDaydreamIntent() {
        return false;
    }

    @Override
    public Intent createVrIntent(final ComponentName componentName) {
        return new Intent();
    }

    @Override
    public boolean launchInVr(final PendingIntent pendingIntent) {
        mLaunchInVrCalled = true;
        return true;
    }

    @Override
    public boolean launchInVr(final Intent intent) {
        return true;
    }

    @Override
    public boolean exitFromVr(int requestCode, final Intent intent) {
        return true;
    }

    @Override
    public Boolean isDaydreamCurrentViewer() {
        return false;
    }

    @Override
    public boolean launchVrHomescreen() {
        return true;
    }

    public boolean getLaunchInVrCalled() {
        return mLaunchInVrCalled;
    }

    @Override
    public boolean bootsToVr() {
        return false;
    }
}
